        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 27 <strong>control</strong><br>0,4,13,15,17,18,19,21,26,27,28,30,32,33,34,35,37,38,39,40,41,43,45,46,47,48,49';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 24 <br>1,2,3,5,6,7,8,9,10,11,12,14,16,20,22,23,24,25,29,31,36,42,44,50';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 27 <strong>control</strong><br>0,4,13,15,17,18,19,21,26,27,28,30,32,33,34,35,37,38,39,40,41,43,45,46,47,48,49';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 24 <br>1,2,3,5,6,7,8,9,10,11,12,14,16,20,22,23,24,25,29,31,36,42,44,50';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 27 <strong>control</strong><br>0,4,13,15,17,18,19,21,26,27,28,30,32,33,34,35,37,38,39,40,41,43,45,46,47,48,49';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 24 <br>1,2,3,5,6,7,8,9,10,11,12,14,16,20,22,23,24,25,29,31,36,42,44,50';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 27 <strong>control</strong><br>0,4,13,15,17,18,19,21,26,27,28,30,32,33,34,35,37,38,39,40,41,43,45,46,47,48,49';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 24 <br>1,2,3,5,6,7,8,9,10,11,12,14,16,20,22,23,24,25,29,31,36,42,44,50';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 27 <strong>control</strong><br>0,4,13,15,17,18,19,21,26,27,28,30,32,33,34,35,37,38,39,40,41,43,45,46,47,48,49';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 24 <br>1,2,3,5,6,7,8,9,10,11,12,14,16,20,22,23,24,25,29,31,36,42,44,50';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 27 <strong>control</strong><br>0,4,13,15,17,18,19,21,26,27,28,30,32,33,34,35,37,38,39,40,41,43,45,46,47,48,49';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260629 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 24 <br>1,2,3,5,6,7,8,9,10,11,12,14,16,20,22,23,24,25,29,31,36,42,44,50';}
}
